@@ -1,7 +1,7 @@
 import base64
 
 from rest_framework import serializers
-from rgd.serializers import ChecksumFileSerializer
+from rgd.serializers import ChecksumFileSerializer, SpatialEntryFootprintSerializer
 from rgd_3d import models
 
 
@@ -29,3 +29,19 @@ class Mesh3DDataSerializer(Mesh3DSerializer):
                 base64_content = base64_content.decode().replace('\n', '')
         ret['vtp_data'] = base64_content
         return ret
+
+
+class Tiles3DSerializer(serializers.ModelSerializer):
+    json_file = ChecksumFileSerializer()
+
+    class Meta:
+        model = models.Tiles3D
+        fields = '__all__'
+
+
+class Tiles3DMetaSerializer(SpatialEntryFootprintSerializer):
+    source = Tiles3DSerializer(read_only=True)
+
+    class Meta:
+        model = models.Tiles3DMeta
+        fields = '__all__'
